pub struct MyCourse {
pub course: Course,
pub can_hide: bool,
}Fields
course: Coursecan_hide: boolWhether the course can be hidden from the “My courses” list. False for courses the user has not enrolled in or has a role in.